import { Component, OnInit } from '@angular/core';
import * as GC from "@grapecity/spread-sheets";
import { TestDataService } from 'src/app/shared/services/testDataService';
import { Items } from 'src/app/shared/model/items';
import { Item } from 'src/app/shared/model/item';

@Component({
  selector: 'app-planning-spreadsheet',
  templateUrl: './planning-spreadsheet.component.html',
  styleUrls: ['./planning-spreadsheet.component.scss']
})
export class PlanningSpreadsheetComponent implements OnInit {

  projectsButtonOptions: any;
  addButtonOption: any;
  spreadBackColor = 'aliceblue';
  sheetName = 'Project X';
  hostStyle = {
    width: '100%',
    height: '100%'
  };
  data = [
    { Name: 'Apple', Category: 'Fruit', Price: 1, 'Shopping Place': 'Wal-Mart' },
    { Name: 'Potato', Category: 'Fruit', Price: 2.01, 'Shopping Place': 'Other' },
    { Name: 'Tomato', Category: 'Vegetable', Price: 3.21, 'Shopping Place': 'Other' },
    { Name: 'Sandwich', Category: 'Food', Price: 2, 'Shopping Place': 'Wal-Mart' },
    { Name: 'Hamburger', Category: 'Food', Price: 2, 'Shopping Place': 'Wal-Mart' },
    { Name: 'Grape', Category: 'Fruit', Price: 4, 'Shopping Place': 'Sun Store' }
  ];
  columnWidth = 100;
  spread: GC.Spread.Sheets.Workbook;
  sheet: GC.Spread.Sheets.Worksheet;
  dataSource: Items;

  workbookInit(args) {
    this.spread = args.spread;
    this.sheet = this.spread.getActiveSheet();
    this.dataSource = this.testDataService.loadItemsBasic();
  }

  constructor(private testDataService: TestDataService) { }

  ngOnInit(): void {
    this.initToolbar();
  }

  initToolbar() {
    this.projectsButtonOptions = {
      text: "set first time",
      stylingMode: "contained",
      onClick: () => { this.changeTestData(); }
    };
    this.addButtonOption = {
      text: "add row",
      stylingMode: "contained",
      onClick: () => { this.addTestData(); }
    };
  }

  changeTestData() {
    
    this.dataSource.items[0].itemName = "hugo";
    let newItem = new Item();
    newItem.itemId = 500;
    newItem.itemName = "hello, a new one";
    newItem.parentItemId = 500;
    newItem.rowIndentLevel = 2;
    newItem.rowIndex = 2
    this.dataSource.items.push(newItem);

    this.bindData();
    this.spread.refresh();
  }

  addTestData() {
    let newItem = new Item();
    newItem.itemId = 500;
    newItem.itemName = "hello, a new one";
    newItem.parentItemId = 500;
    newItem.rowIndentLevel = 2;
    newItem.rowIndex = 2
    this.dataSource.items.push(newItem);
    console.log("adding");
    this.spread.refresh();
  }

  bindData() {
    var colItemId = { name: "itemId", displayName: "Id", size: 70 };
    var colParentItemId = { name: "parentItemId", displayName: "Parent Id", size: 70 };
    var colItemName = { name: "itemName", displayName: "Name", size: 200 };
    var colRowIndentLevel = { name: "rowIndentLevel", displayName: "Level", size: 40 };
    var colRowIndex = { name: "rowIndex", displayName: "Row", size: 40 };
    this.sheet.autoGenerateColumns = false;
    this.sheet.setDataSource(this.dataSource.items, true);
    this.sheet.bindColumn(4, colRowIndex);
    this.sheet.bindColumn(1, colRowIndentLevel);
    this.sheet.bindColumn(2, colItemId);
    this.sheet.bindColumn(3, colParentItemId);
    this.sheet.bindColumn(0, colItemName);
  }

}
